@@ -17,51 +17,42 @@ from contextlib import suppress, AsyncExitStack
 from .changes import change_metadata
 from .log import run_logging
 from .screen import run_screen
-from ..config import Config
+from ..config import BaseConfig, ConfigError
 from ..members import Members
-from ..transport import transport_plugins
+from ..transport import load_transport, Transport
 
 __all__ = ['main']
 
 
 def main() -> int:
     parser = ArgumentParser(description=__doc__)
-    parser.add_argument('-m', '--metadata', nargs=2, metavar=('KEY', 'VAL'),
-                        default=[], action='append', type=_utf8,
-                        help='Metadata for this node.')
-    parser.add_argument('-t', '--transport', metavar='NAME', default='udp',
-                        help='The transport plugin name.')
-    parser.add_argument('-s', '--secret', metavar='STRING',
-                        help='The secret string used to verify messages.')
-    parser.add_argument('-c', '--curses', action='store_true',
-                        help='Enable the curses display.')
-    parser.add_argument('-i', '--token-interval', type=float, default=10.0,
-                        help='Cluster member token update interval.')
-    parser.add_argument('local', metavar='localname',
-                        help='External name or address for this node.')
-    parser.add_argument('peers', metavar='peername', nargs='+',
-                        help='At least one name or address of a known peer.')
-    parser.set_defaults(config_type=Config)
 
-    for transport_name, transport_type in transport_plugins.loaded.items():
-        transport_type.add_arguments(transport_name, parser)
+    transport_type = load_transport()
+    transport_type.config_type.add_arguments(parser)
+
+    group = parser.add_argument_group('swim demo options')
+    group.add_argument('-c', '--curses', action='store_true',
+                       help='Enable the curses display.')
+    group.add_argument('-i', '--token-interval', metavar='SECONDS',
+                       type=float, default=10.0,
+                       help='Cluster member token update interval.')
 
     args = parser.parse_args()
 
     logging.basicConfig(level=logging.INFO,
                         format='%(asctime)-15s %(name)s %(message)s')
 
-    return asyncio.run(run(args))
+    try:
+        return asyncio.run(run(transport_type, args))
+    except ConfigError as exc:
+        parser.error(str(exc))
 
 
-def _utf8(val: str) -> bytes:
-    return val.encode('utf-8')
-
-
-async def run(args: Namespace) -> int:
+async def run(transport_type: type[Transport[BaseConfig]],
+              args: Namespace) -> int:
     loop = asyncio.get_running_loop()
-    config: Config = args.config_type.from_args(args)
-    transport = transport_plugins.choose(args.transport).init(config)
+    config = transport_type.config_type.from_args(args)
+    transport = transport_type(config)
     members = Members(config)
     async with AsyncExitStack() as stack:
         stack.enter_context(suppress(CancelledError))
